# Custom figures

::::{grid} 3

:::{grid-item-card} Subplots / Tiled plots
:link: subplots.ipynb
:img-bottom: ../_static/customization/subplots.png

:::

:::{grid-item-card} Tweaking figures
:link: tweaking-figures.ipynb
:img-bottom: ../_static/customization/tweaking-figures.png

:::

::::{grid-item-card} Building custom interfaces
:link: custom-interfaces.ipynb
:img-bottom: ../_static/customization/custom-interfaces.png

:::

::::

::::{grid} 3

:::{grid-item-card} Graph and node tips
:link: graph-node-tips.ipynb
:img-bottom: ../_static/customization/graph-node-tips.png

:::

::::{grid-item-card} Animations
:link: animations.ipynb
:img-bottom: ../_static/customization/animation_2d.gif

:::

::::

```{toctree}
---
hidden:
---

subplots
tweaking-figures
custom-interfaces
graph-node-tips
animations
```
